@@ -40,6 +40,7 @@ func (fc *File) Init(cacheFilePath string, persist bool) {
 
 	for key, co := range list {
 		if co.Expired() {
+			log.Debug("skipping expired cache key:", key)
 			continue
 		}
 
@@ -50,6 +51,7 @@ func (fc *File) Init(cacheFilePath string, persist bool) {
 
 func (fc *File) Close() {
 	if !fc.persist || !fc.dirty {
+		log.Debug("not persisting cache")
 		return
 	}
 
@@ -65,13 +67,16 @@ func (fc *File) Close() {
 func (fc *File) Get(key string) (string, bool) {
 	val, found := fc.cache.Get(key)
 	if !found {
+		log.Debug("cache key not found:", key)
 		return "", false
 	}
 
 	if co, ok := val.(*Entry); ok {
+		log.Debug("getting cache key:", key, "with value:", co.Value)
 		return co.Value, true
 	}
 
+	log.Debug("unable to parse cache key:", key)
 	return "", false
 }
 
@@ -83,6 +88,8 @@ func (fc *File) Set(key, value string, duration Duration) {
 		return
 	}
 
+	log.Debug("setting cache key:", key, "with duration:", string(duration))
+
 	fc.cache.Set(key, &Entry{
 		Value:     value,
 		Timestamp: time.Now().Unix(),
@@ -94,6 +101,7 @@ func (fc *File) Set(key, value string, duration Duration) {
 
 // delete the key from the cache
 func (fc *File) Delete(key string) {
+	log.Debug("deleting cache key:", key)
 	fc.cache.Delete(key)
 	fc.dirty = true
 }
