@@ -5,16 +5,16 @@ import (
 	"time"
 
 	"github.com/jandedobbeleer/oh-my-posh/src/config"
+	"github.com/jandedobbeleer/oh-my-posh/src/log"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 	"github.com/jandedobbeleer/oh-my-posh/src/shell"
-
+	"github.com/jandedobbeleer/oh-my-posh/src/template"
 	"github.com/spf13/cobra"
 )
 
 var (
 	printOutput bool
 	strict      bool
-	manual      bool
 	debug       bool
 
 	supportedShells = []string{
@@ -51,6 +51,7 @@ See the documentation to initialize your shell: https://ohmyposh.dev/docs/instal
 				_ = cmd.Help()
 				return
 			}
+
 			runInit(args[0])
 		},
 	}
@@ -59,46 +60,56 @@ See the documentation to initialize your shell: https://ohmyposh.dev/docs/instal
 	initCmd.Flags().BoolVarP(&strict, "strict", "s", false, "run in strict mode")
 	initCmd.Flags().BoolVar(&debug, "debug", false, "enable/disable debug mode")
 
-	// Deprecated flags, should be kept to avoid breaking CLI integration.
-	initCmd.Flags().BoolVarP(&manual, "manual", "m", false, "enable/disable manual mode")
-
-	// Hide flags that are deprecated or for internal use only.
-	_ = initCmd.Flags().MarkHidden("manual")
-
 	_ = initCmd.MarkPersistentFlagRequired("config")
 
 	return initCmd
 }
 
-func runInit(shellName string) {
+func runInit(sh string) {
 	var startTime time.Time
+
 	if debug {
 		startTime = time.Now()
+		log.Enable()
+		log.Debug("debug mode enabled")
 	}
 
-	env := &runtime.Terminal{
-		CmdFlags: &runtime.Flags{
-			Shell:  shellName,
-			Config: configFlag,
-			Strict: strict,
-			Debug:  debug,
-			Init:   true,
-		},
+	configFile := config.Path(configFlag)
+	cfg := config.Load(configFile, sh, false)
+
+	flags := &runtime.Flags{
+		Shell:     sh,
+		Config:    configFile,
+		Strict:    strict,
+		Debug:     debug,
+		SaveCache: true,
+		Init:      true,
 	}
 
-	env.Init()
-	defer env.Close()
+	env := &runtime.Terminal{}
+	env.Init(flags)
 
-	cfg := config.Load(env)
+	template.Init(env, cfg.Var)
 
-	feats := cfg.Features()
+	defer func() {
+		template.SaveCache()
+		env.Close()
+	}()
 
-	if printOutput || debug {
-		init := shell.PrintInit(env, feats, &startTime)
-		fmt.Print(init)
+	feats := cfg.Features(env)
+
+	var output string
+
+	switch {
+	case printOutput, debug:
+		output = shell.PrintInit(env, feats, &startTime)
+	default:
+		output = shell.Init(env, feats)
+	}
+
+	if silent {
 		return
 	}
 
-	init := shell.Init(env, feats)
-	fmt.Print(init)
+	fmt.Print(output)
 }
