@@ -5,15 +5,13 @@ import (
 	"strconv"
 
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
-	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 
 	lang "golang.org/x/text/language"
 	"golang.org/x/text/message"
 )
 
 type Executiontime struct {
-	props properties.Properties
-	env   runtime.Environment
+	base
 
 	FormattedMs string
 	Ms          int64
@@ -70,11 +68,6 @@ func (t *Executiontime) Template() string {
 	return " {{ .FormattedMs }} "
 }
 
-func (t *Executiontime) Init(props properties.Properties, env runtime.Environment) {
-	t.props = props
-	t.env = env
-}
-
 func (t *Executiontime) formatDuration(style DurationStyle) string {
 	switch style {
 	case Austin:
