@@ -7,21 +7,16 @@ import (
 //go:embed scripts/omp.zsh
 var zshInit string
 
-const (
-	unixUpgrade = "$_omp_executable upgrade"
-	unixNotice  = "$_omp_executable notice"
-)
-
 func (f Feature) Zsh() Code {
 	switch f {
 	case CursorPositioning:
-		return "_omp_cursor_positioning=1"
+		return unixCursorPositioning
 	case Tooltips:
 		return "enable_poshtooltips"
 	case Transient:
 		return "_omp_create_widget zle-line-init _omp_zle-line-init"
 	case FTCSMarks:
-		return "_omp_ftcs_marks=1"
+		return unixFTCSMarks
 	case Upgrade:
 		return unixUpgrade
 	case Notice:
